# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,trie)
S3method(as.list,trie)
S3method(dim,trie)
S3method(get_keys,integer_trie)
S3method(get_keys,logical_trie)
S3method(get_keys,numeric_trie)
S3method(get_keys,string_trie)
S3method(get_values,integer_trie)
S3method(get_values,logical_trie)
S3method(get_values,numeric_trie)
S3method(get_values,string_trie)
S3method(greedy_match,integer_trie)
S3method(greedy_match,logical_trie)
S3method(greedy_match,numeric_trie)
S3method(greedy_match,string_trie)
S3method(length,integer_trie)
S3method(length,logical_trie)
S3method(length,numeric_trie)
S3method(length,string_trie)
S3method(longest_match,integer_trie)
S3method(longest_match,logical_trie)
S3method(longest_match,numeric_trie)
S3method(longest_match,string_trie)
S3method(prefix_match,integer_trie)
S3method(prefix_match,logical_trie)
S3method(prefix_match,numeric_trie)
S3method(prefix_match,string_trie)
S3method(print,trie)
S3method(str,trie)
S3method(trie_add,integer_trie)
S3method(trie_add,logical_trie)
S3method(trie_add,numeric_trie)
S3method(trie_add,string_trie)
S3method(trie_remove,integer_trie)
S3method(trie_remove,logical_trie)
S3method(trie_remove,numeric_trie)
S3method(trie_remove,string_trie)
export(get_keys)
export(get_values)
export(greedy_match)
export(longest_match)
export(prefix_match)
export(trie)
export(trie_add)
export(trie_remove)
importFrom(Rcpp,sourceCpp)
useDynLib(triebeard, .registration = TRUE)
