#' @title Radix trees in Rcpp
#' @name triebeard
#' @description This package provides access to Radix tree (or "trie") structures in Rcpp. At
#' a later date it will hopefully provide them in R, too.
#'
#' @docType package
#' @aliases triebeard triebeard-package
#' @useDynLib triebeard
#' @importFrom Rcpp sourceCpp
NULL